@@ -1,4 +1,4 @@
-/* $Id: DBIXS.h,v 1.26 1995/10/24 00:24:53 timbo Rel $
+/* $Id: DBIXS.h,v 1.29 1996/01/29 20:02:50 timbo Exp $
  *
  * Copyright (c) 1994, 1995 Tim Bunce
  *
@@ -14,12 +14,6 @@
 #include "XSUB.h"
 
 
-/* Perl5.00[01] should include this if I_MEMORY set but doesn't */
-#ifdef I_MEMORY
-#include <memory.h>
-#endif
-
-
 /* The DBIXS_VERSION value will be incremented whenever new code is
  * added to the interface (this file) or significant changes are made.
  * It's primary goal is to allow newer drivers to compile against an
@@ -32,7 +26,7 @@
 
 #ifdef NEED_DBIXS_VERSION
 #if NEED_DBIXS_VERSION > DBIXS_VERSION
-#error You need to upgrade your DBI module before building this driver.
+error You need to upgrade your DBI module before building this driver.
 #endif
 #endif
 
@@ -75,8 +69,9 @@ typedef struct dbih_com_attr_st {
     /* these are copies of the Hash values (r.c.inc)		*/
     /* many of the hash values are themselves references	*/
     SV *Debug;
-    SV *Err;
-    SV *Errstr;
+    SV *State;		/* Standard SQLSTATE, 5 char string	*/
+    SV *Err;		/* Native engine error code		*/
+    SV *Errstr;		/* Native engine error message		*/
     SV *Handlers;
 } dbih_com_attr_t;
 
@@ -131,6 +126,7 @@ typedef struct {		/* -- STATEMENT --			*/
 #define DBIc_ATTR(imp, field)	_imp2atr(imp, field)
 
 #define DBIc_DEBUGIV(imp)	SvIV(DBIc_ATTR(imp, Debug))
+#define DBIc_STATE(imp)		SvRV(DBIc_ATTR(imp, State))
 #define DBIc_ERR(imp)		SvRV(DBIc_ATTR(imp, Err))
 #define DBIc_ERRSTR(imp)	SvRV(DBIc_ATTR(imp, Errstr))
 #define DBIc_HANDLERS(imp)	SvRV(DBIc_ATTR(imp, Handlers))
@@ -143,7 +139,7 @@ typedef struct {		/* -- STATEMENT --			*/
 #define DBIcf_COMSET	0x0001	/* needs to be clear'd before free'd	*/
 #define DBIcf_IMPSET	0x0002	/* has implementor data to be clear'd	*/
 #define DBIcf_ACTIVE	0x0004	/* needs finish/disconnect before clear	*/
-#define DBIcf_spare	0x0008	/*					*/
+#define DBIcf_spare		0x0008	/*                                      */
 #define DBIcf_WARN  	0x0010	/* warn about poor practice etc		*/
 #define DBIcf_COMPAT  	0x0020	/* compat/emulation mode (eg oraperl)	*/
 
@@ -170,7 +166,7 @@ typedef struct {		/* -- STATEMENT --			*/
 #define DBIc_ACTIVE_off(imp)	/* adjust parent's active kid count */	\
     do {								\
 	imp_xxh_t *ph_com = DBIc_PARENT_COM(imp);			\
-	if (DBIc_ACTIVE(imp) && ph_com && !dirty				\
+	if (DBIc_ACTIVE(imp) && ph_com && !dirty			\
 		&& --DBIc_ACTIVE_KIDS(ph_com) > DBIc_KIDS(ph_com))	\
 	    croak("panic: DBI active kids < 0");			\
 	DBIc_FLAGS(imp) &= ~DBIcf_ACTIVE;				\
@@ -221,10 +217,19 @@ typedef struct {		/* -- STATEMENT --			*/
 #define DBEVENT_event	"DBEVENT"
 #define UNKNOWN_event	"UNKNOWN"
 
+#define DBIh_CLEAR_ERROR(imp_xxh) (void)( \
+	    SvOK_off(DBIc_ERR(imp_xxh)),    	\
+	    SvOK_off(DBIc_ERRSTR(imp_xxh)),	\
+	    (SvPOK(DBIc_STATE(imp_xxh)) ? SvCUR(DBIc_STATE(imp_xxh))=0 : 0)	\
+	)
+
 
 /* --- DBI State Structure --- */
 
 typedef struct {
+
+#define DBISTATE_VERSION  7	/* Must change whenever dbistate_t does	*/
+
     /* version and size are used to check for DBI/DBD version mis-match	*/
     U16 version;	/* version of this structure			*/
     U16 size;
@@ -246,7 +251,6 @@ typedef struct {
     SV *pad2;
 
 } dbistate_t;
-#define DBISTATE_VERSION  7	/* Must change whenever dbistate_t does	*/
 
 #define DBIS              dbis /* default name for dbistate_t variable	*/
 #define DBISTATE_DECLARE  static dbistate_t *DBIS
